django-simpleimages
===================

.. image:: https://img.shields.io/pypi/v/django-simpleimages.svg?style=flat-square   :target: https://pypi.python.org/pypi/django-simpleimages

.. image:: https://img.shields.io/travis/saulshanabrook/django-simpleimages.svg?style=flat-square   :target: https://travis-ci.org/saulshanabrook/django-simpleimages/

.. image:: https://img.shields.io/coveralls/saulshanabrook/django-simpleimages.svg?style=flat-square   :target: https://coveralls.io/r/saulshanabrook/django-simpleimages

.. image:: https://landscape.io/github/saulshanabrook/django-simpleimages/master/landscape.svg?style=flat-square
   :target: https://landscape.io/github/saulshanabrook/django-simpleimages/master
   :alt: Code Health

``django-simpleimages`` is an opinionated Django app which allows you
to transform images on model saves.

http://django-simpleimages.readthedocs.org/

